@@ -9,6 +9,9 @@
 #
 
 
+from init_tests import *
+
+
 __exports = set()
 
 
@@ -17,6 +20,11 @@ for variable in __all__:
     __exports.add(variable)
 
 
+from test_high_level_encryption import *
+for variable in __all__:
+    __exports.add(variable)
+
+
 __all__ = list(__exports)
 
 
